#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_FAST_TOINT_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_FAST_TOINT_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/scalar/fast_toint.hpp>

#endif
